config

package
v0.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 21, 2026 License: GPL-3.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	DefaultPort = 10000
	DefaultBind = "127.0.0.1"
)

Variables

This section is empty.

Functions

func ConfigDir

func ConfigDir() string

ConfigDir returns the pogo configuration directory path.

func ConfigFilePath

func ConfigFilePath() string

ConfigFilePath returns the path to the pogo config file.

Types

type Config

type Config struct {
	Port     int
	Bind     string
	Refinery RefineryConfig
}

Config holds pogo daemon configuration.

func Load

func Load() *Config

Load reads configuration from (in priority order):

  1. POGO_PORT environment variable
  2. ~/.config/pogo/config.toml [server] port field
  3. Default (10000)

func (*Config) ListenAddr

func (c *Config) ListenAddr() string

ListenAddr returns the address string for the server to listen on.

func (*Config) ServerURL

func (c *Config) ServerURL() string

ServerURL returns the base URL for connecting to the pogo daemon.

type RefineryConfig

type RefineryConfig struct {
	Enabled      bool
	PollInterval time.Duration
}

RefineryConfig holds merge queue configuration.

Jump to