Documentation
¶
Index ¶
Constants ¶
const ( DefaultPort = 10000 DefaultBind = "127.0.0.1" )
Variables ¶
This section is empty.
Functions ¶
func ConfigFilePath ¶
func ConfigFilePath() string
ConfigFilePath returns the path to the pogo config file.
Types ¶
type Config ¶
type Config struct {
Port int
Bind string
Refinery RefineryConfig
}
Config holds pogo daemon configuration.
func Load ¶
func Load() *Config
Load reads configuration from (in priority order):
- POGO_PORT environment variable
- ~/.config/pogo/config.toml [server] port field
- Default (10000)
func (*Config) ListenAddr ¶
ListenAddr returns the address string for the server to listen on.
type RefineryConfig ¶
RefineryConfig holds merge queue configuration.
Click to show internal directories.
Click to hide internal directories.